@@ -35,9 +35,13 @@ ARGUMENT_RENAMES = {
     'emr.*.job-flow-ids': 'cluster-ids',
     'emr.*.job-flow-id': 'cluster-id',
     'cloudsearchdomain.search.query': 'search-query',
+    'cloudsearchdomain.suggest.query': 'suggest-query',
     'sns.subscribe.endpoint': 'notification-endpoint',
     'deploy.*.s-3-location': 's3-location',
     'deploy.*.ec-2-tag-filters': 'ec2-tag-filters',
+    'codepipeline.get-pipeline.version': 'pipeline-version',
+    'codepipeline.create-custom-action-type.version': 'action-version',
+    'codepipeline.delete-custom-action-type.version': 'action-version',
 }
 
 
