@@ -17,13 +17,14 @@ import logging
 
 from botocore.exceptions import ProfileNotFound
 
-from awscli.customizations.commands import BasicCommand
 from awscli.compat import raw_input
+from awscli.customizations.commands import BasicCommand
 
 
 logger = logging.getLogger(__name__)
 NOT_SET = '<not set>'
 
+PREDEFINED_SECTION_NAMES = ('preview', 'plugins')
 
 def register_configure_cmd(cli):
     cli.register('building-command-table.main',
@@ -31,6 +32,7 @@ def register_configure_cmd(cli):
 
 
 class ConfigValue(object):
+
     def __init__(self, value, config_type, config_variable):
         self.value = value
         self.config_type = config_type
@@ -54,6 +56,7 @@ def _mask_value(current_value):
 
 
 class InteractivePrompter(object):
+
     def get_value(self, current_value, config_name, prompt_text=''):
         if config_name in ('aws_access_key_id', 'aws_secret_access_key'):
             current_value = _mask_value(current_value)
@@ -218,6 +221,10 @@ class ConfigFileWriter(object):
                 # write out all the values now.
                 self._insert_new_values(i - 1, contents, values, '    ')
                 break
+        else:
+            if starting_indent != current_indent:
+                # The option is the last option in the file
+                self._insert_new_values(i, contents, values, '    ')
         return i
 
     def _insert_new_values(self, line_number, contents, new_values, indent=''):
@@ -403,6 +410,16 @@ class ConfigureSetCommand(BasicCommand):
                 varname = remaining[0]
                 if len(remaining) == 2:
                     value = {remaining[1]: value}
+            elif parts[0] not in PREDEFINED_SECTION_NAMES:
+                if self._session.profile is not None:
+                    section = 'profile %s' % self._session.profile
+                else:
+                    profile_name = self._session.get_config_variable('profile')
+                    if profile_name is not None:
+                        section = profile_name
+                varname = parts[0]
+                if len(parts) == 2:
+                    value = {parts[1]: value}
             elif len(parts) == 2:
                 # Otherwise it's something like "set preview.service true"
                 # of something in the [plugin] section.
@@ -454,9 +471,10 @@ class ConfigureGetCommand(BasicCommand):
             return 1
 
     def _get_dotted_config_value(self, varname):
-        value = None
+        parts = varname.split('.')
         num_dots = varname.count('.')
-        if num_dots == 1:
+        # Logic to deal with predefined sections like [preview], [plugin] and etc.
+        if num_dots == 1 and parts[0] in PREDEFINED_SECTION_NAMES:
             full_config = self._session.full_config
             section, config_name = varname.split('.')
             value = full_config.get(section, {}).get(config_name)
@@ -464,28 +482,29 @@ class ConfigureGetCommand(BasicCommand):
                 # Try to retrieve it from the profile config.
                 value = full_config['profiles'].get(
                     section, {}).get(config_name)
-        elif varname.startswith(('default', 'profile')):
-            # We're hard coding logic for profiles here.  Really
-            # we could support any generic format of [section subsection],
-            # but we'd need some botocore.session changes for that,
-            # and nothing would immediately use that feature.
-            parts = varname.split('.')
-            if parts[0] == 'default':
-                profile_name = 'default'
-                config_name = parts[1]
-                remaining = parts[2:]
-            else:
-                # ['profile', 'profname', 'foo', ...]
-                profile_name = parts[1]
-                config_name = parts[2]
-                remaining = parts[3:]
-            self._session.profile = profile_name
-            value = self._session.get_scoped_config().get(config_name)
-            if len(remaining) == 1:
-                try:
-                    value = value.get(remaining[-1])
-                except AttributeError:
-                    value = None
+            return value
+        if parts[0] == 'profile':
+            profile_name = parts[1]
+            config_name = parts[2]
+            remaining = parts[3:]
+        # Check if varname starts with 'default' profile (e.g. default.emr-dev.emr.instance_profile)
+        # If not, go further to check if varname starts with a known profile name
+        elif parts[0] == 'default' or (parts[0] in self._session.full_config['profiles']):
+            profile_name = parts[0]
+            config_name = parts[1]
+            remaining = parts[2:]
+        else:
+            profile_name = self._session.get_config_variable('profile')
+            config_name = parts[0]
+            remaining = parts[1:]
+
+        value = self._session.full_config['profiles'].get(
+            profile_name, {}).get(config_name)
+        if len(remaining) == 1:
+            try:
+                value = value.get(remaining[-1])
+            except AttributeError:
+                value = None
         return value
 
 
@@ -537,8 +556,6 @@ class ConfigureCommand(BasicCommand):
     def _run_main(self, parsed_args, parsed_globals):
         # Called when invoked with no args "aws configure"
         new_values = {}
-        if parsed_globals.profile is not None:
-            self._session.profile = parsed_globals.profile
         # This is the config from the config file scoped to a specific
         # profile.
         try:
