@@ -18,76 +18,22 @@ import re
 import botocore.exceptions
 from botocore import xform_name
 
-from awscli.customizations.commands import BasicCommand
 from awscli.customizations.emr import configutils
 from awscli.customizations.emr import emrutils
 from awscli.customizations.emr import exceptions
 from awscli.customizations.emr.command import Command
 from awscli.customizations.emr.constants import EC2
 from awscli.customizations.emr.constants import EC2_ROLE_NAME
+from awscli.customizations.emr.constants import EC2_ROLE_ARN_PATTERN
 from awscli.customizations.emr.constants import EMR
 from awscli.customizations.emr.constants import EMR_ROLE_NAME
+from awscli.customizations.emr.constants import EMR_ROLE_ARN_PATTERN
 from awscli.customizations.emr.exceptions import ResolveServicePrincipalError
 
 
 LOG = logging.getLogger(__name__)
 
 
-EC2_ROLE_POLICY = {
-    "Statement": [
-        {
-            "Action": [
-                "cloudwatch:*",
-                "dynamodb:*",
-                "ec2:Describe*",
-                "elasticmapreduce:Describe*",
-                "rds:Describe*",
-                "s3:*",
-                "sdb:*",
-                "sns:*",
-                "sqs:*"
-            ],
-            "Effect": "Allow",
-            "Resource": ["*"]
-        }
-    ]
-}
-
-
-EMR_ROLE_POLICY = {
-    "Version": "2012-10-17",
-    "Statement": [
-        {
-            "Action": [
-                "ec2:AuthorizeSecurityGroupIngress",
-                "ec2:CancelSpotInstanceRequests",
-                "ec2:CreateSecurityGroup",
-                "ec2:CreateTags",
-                "ec2:Describe*",
-                "ec2:DeleteTags",
-                "ec2:ModifyImageAttribute",
-                "ec2:ModifyInstanceAttribute",
-                "ec2:RequestSpotInstances",
-                "ec2:RunInstances",
-                "ec2:TerminateInstances",
-                "iam:PassRole",
-                "iam:ListRolePolicies",
-                "iam:GetRole",
-                "iam:GetRolePolicy",
-                "iam:ListInstanceProfiles",
-                "s3:Get*",
-                "s3:List*",
-                "s3:CreateBucket",
-                "sdb:BatchPutAttributes",
-                "sdb:Select"
-            ],
-            "Effect": "Allow",
-            "Resource": "*"
-        }
-    ]
-}
-
-
 def assume_role_policy(serviceprincipal):
     return {
         "Version": "2008-10-17",
@@ -102,6 +48,26 @@ def assume_role_policy(serviceprincipal):
     }
 
 
+def get_service_role_policy_arn(region):
+    region_suffix = _get_policy_arn_suffix(region)
+    return EMR_ROLE_ARN_PATTERN.replace("{{region_suffix}}", region_suffix)
+
+
+def get_ec2_role_policy_arn(region):
+    region_suffix = _get_policy_arn_suffix(region)
+    return EC2_ROLE_ARN_PATTERN.replace("{{region_suffix}}", region_suffix)
+
+
+def _get_policy_arn_suffix(region):
+    region_string = region.lower()
+    if region_string.startswith("cn-"):
+        return "aws-cn"
+    elif region_string.startswith("us-gov"):
+        return "aws-us-gov"
+    else:
+        return "aws"
+
+
 def get_service_principal(service, endpoint_host):
     return service + '.' + _get_suffix(endpoint_host)
 
@@ -138,8 +104,10 @@ class CreateDefaultRoles(Command):
     NAME = "create-default-roles"
     DESCRIPTION = ('Creates the default IAM role ' +
                    EC2_ROLE_NAME + ' and ' +
-                   EMR_ROLE_NAME + ' which can be used when'
-                   ' creating the cluster using the create-cluster command.\n'
+                   EMR_ROLE_NAME + ' which can be used when creating the'
+                   ' cluster using the create-cluster command. The default'
+                   ' roles for EMR use managed policies, which are updated'
+                   ' automatically to support future EMR functionality.\n'
                    '\nIf you do not have a Service Role and Instance Profile '
                    'variable set for your create-cluster command in the AWS '
                    'CLI config file, create-default-roles will automatically '
@@ -158,11 +126,13 @@ class CreateDefaultRoles(Command):
                       ' custom endpoint should be called for IAM operations'
                       '.</p>'}
     ]
-    EXAMPLES = BasicCommand.FROM_FILE('emr', 'create-default-roles.rst')
 
     def _run_main_command(self, parsed_args, parsed_globals):
         ec2_result = None
+        ec2_policy = None
         emr_result = None
+        emr_policy = None
+
         self.iam_endpoint_url = parsed_args.iam_endpoint
 
         self._check_for_iam_endpoint(self.region, self.iam_endpoint_url)
@@ -183,10 +153,10 @@ class CreateDefaultRoles(Command):
         else:
             LOG.debug('Role ' + role_name + ' does not exist.'
                       ' Creating default role for EC2: ' + role_name)
+            role_arn = get_ec2_role_policy_arn(self.region)
             ec2_result = self._create_role_with_role_policy(
-                role_name, role_name, EC2,
-                emrutils.dict_to_string(EC2_ROLE_POLICY),
-                parsed_globals)
+                role_name, EC2, role_arn, parsed_globals)
+            ec2_policy = self._get_role_policy(role_arn, parsed_globals)
 
         # Check if the default EC2 Instance Profile for EMR exists.
         instance_profile_name = EC2_ROLE_NAME
@@ -208,17 +178,17 @@ class CreateDefaultRoles(Command):
         else:
             LOG.debug('Role ' + role_name + ' does not exist.'
                       ' Creating default role for EMR: ' + role_name)
+            role_arn = get_service_role_policy_arn(self.region)
             emr_result = self._create_role_with_role_policy(
-                role_name, role_name, EMR,
-                emrutils.dict_to_string(EMR_ROLE_POLICY),
-                parsed_globals)
+                role_name, EMR, role_arn, parsed_globals)
+            emr_policy = self._get_role_policy(role_arn, parsed_globals)
 
         configutils.update_roles(self._session)
-
         emrutils.display_response(
             self._session,
             'create_role',
-            self._construct_result(ec2_result, emr_result),
+            self._construct_result(ec2_result, ec2_policy,
+                                   emr_result, emr_policy),
             parsed_globals)
 
         return 0
@@ -230,19 +200,19 @@ class CreateDefaultRoles(Command):
             if iam_endpoint is None:
                 raise exceptions.UnknownIamEndpointError(region=region)
 
-    def _construct_result(self, ec2_response, emr_response):
+    def _construct_result(self, ec2_response, ec2_policy,
+                          emr_response, emr_policy):
         result = []
         self._construct_role_and_role_policy_structure(
-            result, ec2_response, EC2_ROLE_POLICY)
+            result, ec2_response, ec2_policy)
         self._construct_role_and_role_policy_structure(
-            result, emr_response, EMR_ROLE_POLICY)
+            result, emr_response, emr_policy)
         return result
 
     def _construct_role_and_role_policy_structure(
-            self, list, response, role_policy):
-        if response is not None and response[1] is not None:
-            list.append({'Role': response[1]['Role'],
-                         'RolePolicy': role_policy})
+            self, list, response, policy):
+        if response is not None and response['Role'] is not None:
+            list.append({'Role': response['Role'], 'RolePolicy': policy})
             return list
 
     def _check_if_role_exists(self, role_name, parsed_globals):
@@ -252,7 +222,7 @@ class CreateDefaultRoles(Command):
         except Exception as e:
             role_not_found_msg = 'The role with name ' + role_name +\
                                  ' cannot be found'
-            if role_not_found_msg in e.message:
+            if role_not_found_msg in e.error_message:
                 # No role error.
                 return False
             else:
@@ -271,7 +241,7 @@ class CreateDefaultRoles(Command):
             profile_not_found_msg = 'Instance Profile ' +\
                                     instance_profile_name +\
                                     ' cannot be found.'
-            if profile_not_found_msg in e.message:
+            if profile_not_found_msg in e.error_message:
                 # No instance profile error.
                 return False
             else:
@@ -280,9 +250,19 @@ class CreateDefaultRoles(Command):
 
         return True
 
+    def _get_role_policy(self, arn, parsed_globals):
+        parameters = {}
+        parameters['PolicyArn'] = arn
+        policy_details = self._call_iam_operation('GetPolicy', parameters,
+                                                  parsed_globals)
+        parameters["VersionId"] = policy_details["Policy"]["DefaultVersionId"]
+        policy_version_details = self._call_iam_operation('GetPolicyVersion',
+                                                          parameters,
+                                                          parsed_globals)
+        return policy_version_details["PolicyVersion"]["Document"]
+
     def _create_role_with_role_policy(
-            self, role_name, policy_name, service_name, policy_document,
-            parsed_globals):
+            self, role_name, service_name, role_arn, parsed_globals):
         service_principal = get_service_principal(service_name,
                                                   self.emr_endpoint_url)
         LOG.debug(service_principal)
@@ -296,10 +276,10 @@ class CreateDefaultRoles(Command):
                                                         parsed_globals)
 
         parameters = {}
-        parameters['PolicyDocument'] = policy_document
-        parameters['PolicyName'] = policy_name
+        parameters['PolicyArn'] = role_arn
         parameters['RoleName'] = role_name
-        self._call_iam_operation('PutRolePolicy', parameters, parsed_globals)
+        self._call_iam_operation('AttachRolePolicy',
+                                 parameters, parsed_globals)
 
         return create_role_response
 
