@@ -307,7 +307,6 @@ class ListCommand(S3Command):
     ARG_TABLE = [{'name': 'paths', 'nargs': '?', 'default': 's3://',
                   'positional_arg': True, 'synopsis': USAGE}, RECURSIVE,
                  PAGE_SIZE, HUMAN_READABLE, SUMMARIZE]
-    EXAMPLES = BasicCommand.FROM_FILE('s3/ls.rst')
 
     def _run_main(self, parsed_args, parsed_globals):
         super(ListCommand, self)._run_main(parsed_args, parsed_globals)
@@ -348,7 +347,7 @@ class ListCommand(S3Command):
         paginator = self.client.get_paginator('list_objects')
         iterator = paginator.paginate(Bucket=bucket,
                                       Prefix=key, Delimiter='/',
-                                      page_size=page_size)
+                                      PaginationConfig={'PageSize': page_size})
         for response_data in iterator:
             self._display_page(response_data)
 
@@ -390,7 +389,8 @@ class ListCommand(S3Command):
     def _list_all_objects_recursive(self, bucket, key, page_size=None):
         paginator = self.client.get_paginator('list_objects')
         iterator = paginator.paginate(Bucket=bucket,
-                                      Prefix=key, page_size=page_size)
+                                      Prefix=key,
+                                      PaginationConfig={'PageSize': page_size})
         for response_data in iterator:
             self._display_page(response_data, use_basename=False)
 
@@ -550,7 +550,6 @@ class CpCommand(S3TransferCommand):
     ARG_TABLE = [{'name': 'paths', 'nargs': 2, 'positional_arg': True,
                   'synopsis': USAGE}] + TRANSFER_ARGS + \
                 [METADATA_DIRECTIVE, EXPECTED_SIZE, RECURSIVE]
-    EXAMPLES = BasicCommand.FROM_FILE('s3/cp.rst')
 
 
 class MvCommand(S3TransferCommand):
@@ -562,8 +561,6 @@ class MvCommand(S3TransferCommand):
     ARG_TABLE = [{'name': 'paths', 'nargs': 2, 'positional_arg': True,
                   'synopsis': USAGE}] + TRANSFER_ARGS + [METADATA_DIRECTIVE,
                                                          RECURSIVE]
-    EXAMPLES = BasicCommand.FROM_FILE('s3/mv.rst')
-
 
 class RmCommand(S3TransferCommand):
     NAME = 'rm'
@@ -572,17 +569,18 @@ class RmCommand(S3TransferCommand):
     ARG_TABLE = [{'name': 'paths', 'nargs': 1, 'positional_arg': True,
                   'synopsis': USAGE}, DRYRUN, QUIET, RECURSIVE, INCLUDE,
                  EXCLUDE, ONLY_SHOW_ERRORS, PAGE_SIZE]
-    EXAMPLES = BasicCommand.FROM_FILE('s3/rm.rst')
 
 
 class SyncCommand(S3TransferCommand):
     NAME = 'sync'
-    DESCRIPTION = "Syncs directories and S3 prefixes."
+    DESCRIPTION = "Syncs directories and S3 prefixes. Recursively copies " \
+                  "new and updated files from the source directory to " \
+                  "the destination. Only creates folders in the destination " \
+                  "if they contain one or more files."
     USAGE = "<LocalPath> <S3Path> or <S3Path> " \
             "<LocalPath> or <S3Path> <S3Path>"
     ARG_TABLE = [{'name': 'paths', 'nargs': 2, 'positional_arg': True,
                   'synopsis': USAGE}] + TRANSFER_ARGS
-    EXAMPLES = BasicCommand.FROM_FILE('s3/sync.rst')
 
 
 class MbCommand(S3TransferCommand):
@@ -591,7 +589,6 @@ class MbCommand(S3TransferCommand):
     USAGE = "<S3Path>"
     ARG_TABLE = [{'name': 'paths', 'nargs': 1, 'positional_arg': True,
                   'synopsis': USAGE}]
-    EXAMPLES = BasicCommand.FROM_FILE('s3/mb.rst')
 
 
 class RbCommand(S3TransferCommand):
@@ -600,7 +597,6 @@ class RbCommand(S3TransferCommand):
     USAGE = "<S3Path>"
     ARG_TABLE = [{'name': 'paths', 'nargs': 1, 'positional_arg': True,
                   'synopsis': USAGE}, FORCE]
-    EXAMPLES = BasicCommand.FROM_FILE('s3/rb.rst')
 
 
 class CommandArchitecture(object):
