@@ -58,9 +58,14 @@ from awscli.customizations.configservice.subscribe import register_subscribe
 from awscli.customizations.configservice.getstatus import register_get_status
 from awscli.customizations.configservice.rename_cmd import \
     register_rename_config
+from awscli.customizations.configservice.putconfigurationrecorder import \
+    register_modify_put_configuration_recorder
 from awscli.customizations.scalarparse import register_scalar_parser
 from awscli.customizations.opsworks import initialize as opsworks_init
 from awscli.customizations.awslambda import register_lambda_create_function
+from awscli.customizations.kms import register_fix_kms_create_grant_docs
+from awscli.customizations.route53 import register_create_hosted_zone_doc_fix
+from awscli.customizations.codecommit import initialize as codecommit_init
 
 
 def awscli_initialize(event_handlers):
@@ -124,3 +129,7 @@ def awscli_initialize(event_handlers):
     register_scalar_parser(event_handlers)
     opsworks_init(event_handlers)
     register_lambda_create_function(event_handlers)
+    register_fix_kms_create_grant_docs(event_handlers)
+    register_create_hosted_zone_doc_fix(event_handlers)
+    register_modify_put_configuration_recorder(event_handlers)
+    codecommit_init(event_handlers)
