@@ -34,6 +34,8 @@ import string
 from pprint import pformat
 from subprocess import Popen, PIPE
 
+from awscli.compat import StringIO
+
 
 try:
     import mock
@@ -82,8 +84,10 @@ AWS_CMD = None
 def create_clidriver():
     driver = awscli.clidriver.create_clidriver()
     session = driver.session
-    data_path = session.get_config_variable('data_path')
-    _LOADER.data_path = data_path or ''
+    data_path = session.get_config_variable('data_path').split(os.pathsep)
+    if not data_path:
+        data_path = []
+    _LOADER.search_paths.extend(data_path)
     session.register_component('data_loader', _LOADER)
     return driver
 
@@ -180,7 +184,8 @@ class BaseCLIDriverTest(unittest.TestCase):
         self.environ_patch = mock.patch('os.environ', self.environ)
         self.environ_patch.start()
         emitter = HierarchicalEmitter()
-        session = Session(EnvironmentVariables, emitter, loader=_LOADER)
+        session = Session(EnvironmentVariables, emitter)
+        session.register_component('data_loader', _LOADER)
         load_plugins({}, event_hooks=emitter)
         driver = CLIDriver(session=session)
         self.session = session
@@ -208,6 +213,14 @@ class BaseAWSHelpOutputTest(BaseCLIDriverTest):
                       "actual rendered contents:\n%s" % (
                           contains, self.renderer.rendered_contents))
 
+    def assert_contains_with_count(self, contains, count):
+        r_count = self.renderer.rendered_contents.count(contains)
+        if r_count != count:
+            self.fail("The expected contents:\n%s\n, with the "
+                      "count:\n%d\nwere not in the actual rendered "
+                      " contents:\n%s\nwith count:\n%d" % (
+                          contains, count, self.renderer.rendered_contents, r_count))
+
     def assert_not_contains(self, contents):
         if contents in self.renderer.rendered_contents:
             self.fail("The contents:\n%s\nwere not suppose to be in the "
@@ -694,3 +707,8 @@ class BaseS3CLICommand(unittest.TestCase):
         self.assertNotIn("failed:", p.stderr)
         self.assertNotIn("client error", p.stderr)
         self.assertNotIn("server error", p.stderr)
+
+
+class StringIOWithFileNo(StringIO):
+    def fileno(self):
+        return 0
